"""

Smoke testing of the viz module.

"""

import numpy as np
import numpy.testing as npt
import pytest

from nitime.timeseries import TimeSeries
from nitime.analysis import CorrelationAnalyzer
from nitime.viz import drawmatrix_channels, drawgraph_channels, plot_xcorr

try:
    import networkx
    no_networkx = False
    no_networkx_msg = ''
except ImportError as e:
    no_networkx = True
    no_networkx_msg = e.args[0]

import os
is_ci = "CI" in os.environ

roi_names = ['a','b','c','d','e','f','g','h','i','j']
data = np.random.rand(10,1024)

T = TimeSeries(data, sampling_interval=np.pi)
T.metadata['roi'] = roi_names

#Initialize the correlation analyzer
C = CorrelationAnalyzer(T)

@pytest.mark.skipif(is_ci, reason="Running on a CI server")
def test_drawmatrix_channels():
    fig01 = drawmatrix_channels(C.corrcoef, roi_names, size=[10., 10.], color_anchor=0)

@pytest.mark.skipif(is_ci, reason="Running on a CI server")
def test_plot_xcorr():
    xc = C.xcorr_norm

    fig02 = plot_xcorr(xc,
                       ((0, 1),
                        (2, 3)),
                       line_labels=['a', 'b'])


@pytest.mark.skipif(is_ci, reason="Running on a CI server")
@pytest.mark.skipif(no_networkx, reason=no_networkx_msg)
def test_drawgraph_channels():
    fig04 = drawgraph_channels(C.corrcoef, roi_names)



print("import: 'nitime'")
import nitime

print("import: 'nitime.algorithms'")
import nitime.algorithms

print("import: 'nitime.algorithms.tests'")
import nitime.algorithms.tests

print("import: 'nitime.analysis'")
import nitime.analysis

print("import: 'nitime.analysis.tests'")
import nitime.analysis.tests

print("import: 'nitime.fmri'")
import nitime.fmri

print("import: 'nitime.fmri.tests'")
import nitime.fmri.tests

print("import: 'nitime.tests'")
import nitime.tests




"""nitime version/release information"""

# Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
_version_major = 0
_version_minor = 7
_version_micro = ''  # use '' for first of series, number for 1 and above
#_version_extra = 'dev'
_version_extra = ''  # Uncomment this for full releases

# Construct full version string from these.
_ver = [_version_major, _version_minor]
if _version_micro:
    _ver.append(_version_micro)
if _version_extra:
    _ver.append(_version_extra)

__version__ = '.'.join(map(str, _ver))

CLASSIFIERS = ["Development Status :: 3 - Alpha",
               "Environment :: Console",
               "Intended Audience :: Science/Research",
               "License :: OSI Approved :: BSD License",
               "Operating System :: OS Independent",
               "Programming Language :: Python",
               "Topic :: Scientific/Engineering"]

description = "Nitime: timeseries analysis for neuroscience data"

# Note: this long_description is actually a copy/paste from the top-level
# README.txt, so that it shows up nicely on PyPI.  So please remember to edit
# it only in one place and sync it correctly.
long_description = """
===================================================
 Nitime: timeseries analysis for neuroscience data
===================================================

Nitime is library of tools and algorithms for the analysis of time-series data
from neuroscience experiments. It contains a implementation of numerical
algorithms for time-series analysis both in the time and spectral domains, a
set of container objects to represent time-series, and auxiliary objects that
expose a high level interface to the numerical machinery and make common
analysis tasks easy to express with compact and semantically clear code.

Website and mailing list
========================

Current information can always be found at the nitime `website`_. Questions and
comments can be directed to the mailing `list`_.

.. _website: http://nipy.org/nitime
.. _list: http://mail.scipy.org/mailman/listinfo/nipy-devel

Code
====

You can find our sources and single-click downloads:

* `Main repository`_ on Github.
* Documentation_ for all releases and current development tree.
* Download as a tar/zip file the `current trunk`_.
* Downloads of all `available releases`_.

.. _main repository: http://github.com/nipy/nitime
.. _Documentation: http://nipy.org/nitime
.. _current trunk: http://github.com/nipy/nitime/archives/master
.. _available releases: http://github.com/nipy/nitime/downloads


License information
===================

Nitime is licensed under the terms of the new BSD license. See the file
"LICENSE" for information on the history of this software, terms & conditions
for usage, and a DISCLAIMER OF ALL WARRANTIES.

All trademarks referenced herein are property of their respective holders.

Copyright (c) 2006-2014, NIPY Developers
All rights reserved.
"""

NAME = "nitime"
MAINTAINER = "Nipy Developers"
MAINTAINER_EMAIL = "nipy-devel@neuroimaging.scipy.org"
DESCRIPTION = description
LONG_DESCRIPTION = long_description
URL = "http://nipy.org/nitime"
DOWNLOAD_URL = "http://github.com/nipy/nitime/downloads"
LICENSE = "Simplified BSD"
AUTHOR = "Nitime developers"
AUTHOR_EMAIL = "nipy-devel@neuroimaging.scipy.org"
PLATFORMS = "OS Independent"
MAJOR = _version_major
MINOR = _version_minor
MICRO = _version_micro
VERSION = __version__
PACKAGE_DATA = {"nitime": ["LICENSE", "tests/*.txt", "tests/*.npy",
                                  "data/*.nii.gz","data/*.txt", "data/*.csv"]}
REQUIRES = ["numpy", "matplotlib", "scipy"]



"""
This module contains implementations of algorithms for time series
analysis. These algorithms include:

1. Spectral estimation: calculate the spectra of time-series and cross-spectra
between time-series.

:func:`get_spectra`, :func:`get_spectra_bi`, :func:`periodogram`,
:func:`periodogram_csd`, :func:`dpss_windows`, :func:`multi_taper_psd`,
:func:`multi_taper_csd`, :func:`mtm_cross_spectrum`

2. Coherency: calculate the pairwise correlation between time-series in the
frequency domain and related quantities.

:func:`coherency`, :func:`coherence`, :func:`coherence_regularized`,
:func:`coherency_regularized`, :func:`coherency_bavg`, :func:`coherence_bavg`,
:func:`coherence_partial`, :func:`coherence_partial_bavg`,
:func:`coherency_phase_spectrum`, :func:`coherency_phase_delay`,
:func:`coherency_phase_delay_bavg`, :func:`correlation_spectrum`

3. Cached coherency: A set of special functions for quickly calculating
coherency in large data-sets, where the calculation is done over only a subset
of the adjacency matrix edges and intermediate calculations are cached, in
order to save calculation time.

:func:`cache_fft`, :func:`cache_to_psd`, :func:`cache_to_phase`,
:func:`cache_to_relative_phase`, :func:`cache_to_coherency`.

4. Event-related analysis: calculate the correlation between time-series and
external events.

:func:`freq_domain_xcorr`, :func:`freq_domain_xcorr_zscored`, :func:`fir`

5. Wavelet transforms: Calculate wavelet transforms of time-series data.

:func:`wmorlet`, :func:`wfmorlet_fft`, :func:`wlogmorlet`,
:func:`wlogmorlet_fft`

6. Filtering: Filter a signal in the frequency domain.

:func:`boxcar_filter`

7. Autoregressive estimation and granger causality

:func:

The algorithms in this library are the functional form of the algorithms, which
accept as inputs numpy array and produce numpy array outputs. Therfore, they
can be used on any type of data which can be represented in numpy arrays. See
also :mod:`nitime.analysis` for simplified analysis interfaces, using the
data containers implemented in :mod:`nitime.timeseries`


"""
from nitime.algorithms.spectral import *
from nitime.algorithms.cohere import *
from nitime.algorithms.wavelet import *
from nitime.algorithms.event_related import *
from nitime.algorithms.autoregressive import *
from nitime.algorithms.filter import *
from nitime.algorithms.correlation import *
